## Data for radionuclide spectra (ICRP107)

The file `icrp107.json` was created based in the publication [ICRP, 2008. Nuclear Decay Data for Dosimetric Calculations. ICRP Publication 107. Ann. ICRP 38](https://www.icrp.org/publication.asp?id=ICRP%20Publication%20107) with the data from the [Supplemental material](https://journals.sagepub.com/doi/suppl/10.1177/ANIB_38_3).
[Direct link to the zipped data](https://journals.sagepub.com/doi/suppl/10.1177/ANIB_38_3/suppl_file/P107JAICRP_38_3_Nuclear_Decay_Data_suppl_data.zip)

The database contains information on the half-lives, decay chains, and yields and energies of radiations emitted in nuclear transformations of 1252 radionuclides of 97 elements.

We need this data as a Python module for [opengate](https://github.com/OpenGATE/opengate).
